@@ -1,4 +1,3 @@
-from enum import Enum
 from pathlib import Path
 
 from nonebot import require, get_driver, get_plugin_config
@@ -6,7 +5,7 @@ from apilmoji import ELK_SH_CDN, EmojiStyle
 from pydantic import BaseModel
 from bilibili_api.video import VideoCodecs, VideoQuality
 
-from .constants import PlatformEnum
+from .constants import RenderType, PlatformEnum
 
 require("nonebot_plugin_localstore")
 import nonebot_plugin_localstore as _store
@@ -16,12 +15,6 @@ _config_dir: Path = _store.get_plugin_config_dir()
 _data_dir: Path = _store.get_plugin_data_dir()
 
 
-class RenderType(str, Enum):
-    default = "default"
-    common = "common"
-    htmlkit = "htmlkit"
-
-
 class Config(BaseModel):
     parser_bili_ck: str | None = None
     """bilibili cookies"""
